==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/NatRuleConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.NatRuleConditionArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.FirewallPolicyRuleConditionNetworkProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Rule condition of type nat.
 * @property description Description of the rule condition.
 * @property destinationAddresses List of destination IP addresses or Service Tags.
 * @property destinationPorts List of destination ports.
 * @property ipProtocols Array of FirewallPolicyRuleConditionNetworkProtocols.
 * @property name Name of the rule condition.
 * @property ruleConditionType Rule Condition Type.
 * Expected value is 'NatRuleCondition'.
 * @property sourceAddresses List of source IP addresses for this rule.
 * @property sourceIpGroups List of source IpGroups for this rule.
 */
public data class NatRuleConditionArgs(
    public val description: Output<String>? = null,
    public val destinationAddresses: Output<List<String>>? = null,
    public val destinationPorts: Output<List<String>>? = null,
    public val ipProtocols: Output<List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>? =
        null,
    public val name: Output<String>? = null,
    public val ruleConditionType: Output<String>,
    public val sourceAddresses: Output<List<String>>? = null,
    public val sourceIpGroups: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.NatRuleConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.NatRuleConditionArgs =
        com.pulumi.azurenative.network.inputs.NatRuleConditionArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .destinationAddresses(destinationAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .destinationPorts(destinationPorts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ipProtocols(
                ipProtocols?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .ruleConditionType(ruleConditionType.applyValue({ args0 -> args0 }))
            .sourceAddresses(sourceAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sourceIpGroups(sourceIpGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [NatRuleConditionArgs].
 */
@PulumiTagMarker
public class NatRuleConditionArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var destinationAddresses: Output<List<String>>? = null

    private var destinationPorts: Output<List<String>>? = null

    private var ipProtocols: Output<List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>? =
        null

    private var name: Output<String>? = null

    private var ruleConditionType: Output<String>? = null

    private var sourceAddresses: Output<List<String>>? = null

    private var sourceIpGroups: Output<List<String>>? = null

    /**
     * @param value Description of the rule condition.
     */
    @JvmName("csarofsknygcffah")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value List of destination IP addresses or Service Tags.
     */
    @JvmName("vcxymnnguwxgufnr")
    public suspend fun destinationAddresses(`value`: Output<List<String>>) {
        this.destinationAddresses = value
    }

    @JvmName("vigsslorfxsaskly")
    public suspend fun destinationAddresses(vararg values: Output<String>) {
        this.destinationAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of destination IP addresses or Service Tags.
     */
    @JvmName("ghtbucunmjafgova")
    public suspend fun destinationAddresses(values: List<Output<String>>) {
        this.destinationAddresses = Output.all(values)
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("gipngwgabvxnyajf")
    public suspend fun destinationPorts(`value`: Output<List<String>>) {
        this.destinationPorts = value
    }

    @JvmName("evwlcmpipjikjupb")
    public suspend fun destinationPorts(vararg values: Output<String>) {
        this.destinationPorts = Output.all(values.asList())
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("pcuxcrhmdkvsdhku")
    public suspend fun destinationPorts(values: List<Output<String>>) {
        this.destinationPorts = Output.all(values)
    }

    /**
     * @param value Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("xehyrqiuucvvikrd")
    public suspend
    fun ipProtocols(`value`: Output<List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>) {
        this.ipProtocols = value
    }

    @JvmName("gcchqxuynqvakdnj")
    public suspend fun ipProtocols(
        vararg
        values: Output<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>,
    ) {
        this.ipProtocols = Output.all(values.asList())
    }

    /**
     * @param values Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("yqojfniqsljmfwls")
    public suspend
    fun ipProtocols(values: List<Output<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>) {
        this.ipProtocols = Output.all(values)
    }

    /**
     * @param value Name of the rule condition.
     */
    @JvmName("lgxoyqmfbsdbksns")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Rule Condition Type.
     * Expected value is 'NatRuleCondition'.
     */
    @JvmName("htqbbbebotqgdcci")
    public suspend fun ruleConditionType(`value`: Output<String>) {
        this.ruleConditionType = value
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("mregqfsuxgxuvdty")
    public suspend fun sourceAddresses(`value`: Output<List<String>>) {
        this.sourceAddresses = value
    }

    @JvmName("avsjakrlkslaijnc")
    public suspend fun sourceAddresses(vararg values: Output<String>) {
        this.sourceAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("wnbsggmhpjslrgdl")
    public suspend fun sourceAddresses(values: List<Output<String>>) {
        this.sourceAddresses = Output.all(values)
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("qncjoflfrasxdplj")
    public suspend fun sourceIpGroups(`value`: Output<List<String>>) {
        this.sourceIpGroups = value
    }

    @JvmName("vhuredkxhfnxpbyo")
    public suspend fun sourceIpGroups(vararg values: Output<String>) {
        this.sourceIpGroups = Output.all(values.asList())
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("whnyxcefjrhqxkex")
    public suspend fun sourceIpGroups(values: List<Output<String>>) {
        this.sourceIpGroups = Output.all(values)
    }

    /**
     * @param value Description of the rule condition.
     */
    @JvmName("dyglptdlyjdjcjwi")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value List of destination IP addresses or Service Tags.
     */
    @JvmName("cfiipkyiasqeettn")
    public suspend fun destinationAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param values List of destination IP addresses or Service Tags.
     */
    @JvmName("kmhvettmkseorvds")
    public suspend fun destinationAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("pjahrvsyajdpydew")
    public suspend fun destinationPorts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("hcsoxcucmofwhvxr")
    public suspend fun destinationPorts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param value Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("ddahatacmnioxjkm")
    public suspend
    fun ipProtocols(`value`: List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipProtocols = mapped
    }

    /**
     * @param values Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("gttooqhmyalyqrlt")
    public suspend fun ipProtocols(
        vararg
        values: Either<String, FirewallPolicyRuleConditionNetworkProtocol>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipProtocols = mapped
    }

    /**
     * @param value Name of the rule condition.
     */
    @JvmName("nqwgsfrvcmwjmwgk")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Rule Condition Type.
     * Expected value is 'NatRuleCondition'.
     */
    @JvmName("uqlohmmpnlqiticg")
    public suspend fun ruleConditionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleConditionType = mapped
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("njfqxxmoanjdccpi")
    public suspend fun sourceAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("rjhlanghrjjdjjkw")
    public suspend fun sourceAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("pbouvvuwcsrqdlks")
    public suspend fun sourceIpGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("juupdvdrhcfpcxyo")
    public suspend fun sourceIpGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    internal fun build(): NatRuleConditionArgs = NatRuleConditionArgs(
        description = description,
        destinationAddresses = destinationAddresses,
        destinationPorts = destinationPorts,
        ipProtocols = ipProtocols,
        name = name,
        ruleConditionType = ruleConditionType ?: throw PulumiNullFieldException("ruleConditionType"),
        sourceAddresses = sourceAddresses,
        sourceIpGroups = sourceIpGroups,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/NatRuleConditionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.NatRuleConditionArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.FirewallPolicyRuleConditionNetworkProtocol
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Rule condition of type nat.
 * @property description Description of the rule condition.
 * @property destinationAddresses List of destination IP addresses or Service Tags.
 * @property destinationPorts List of destination ports.
 * @property ipProtocols Array of FirewallPolicyRuleConditionNetworkProtocols.
 * @property name Name of the rule condition.
 * @property ruleConditionType Rule Condition Type.
 * Expected value is 'NatRuleCondition'.
 * @property sourceAddresses List of source IP addresses for this rule.
 * @property sourceIpGroups List of source IpGroups for this rule.
 */
public data class NatRuleConditionArgs(
    public val description: Output<String>? = null,
    public val destinationAddresses: Output<List<String>>? = null,
    public val destinationPorts: Output<List<String>>? = null,
    public val ipProtocols: Output<List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>? =
        null,
    public val name: Output<String>? = null,
    public val ruleConditionType: Output<String>,
    public val sourceAddresses: Output<List<String>>? = null,
    public val sourceIpGroups: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.NatRuleConditionArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.NatRuleConditionArgs =
        com.pulumi.azurenative.network.inputs.NatRuleConditionArgs.builder()
            .description(description?.applyValue({ args0 -> args0 }))
            .destinationAddresses(destinationAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .destinationPorts(destinationPorts?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .ipProtocols(
                ipProtocols?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.transform({ args0 ->
                            args0
                        }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                    })
                }),
            )
            .name(name?.applyValue({ args0 -> args0 }))
            .ruleConditionType(ruleConditionType.applyValue({ args0 -> args0 }))
            .sourceAddresses(sourceAddresses?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .sourceIpGroups(sourceIpGroups?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [NatRuleConditionArgs].
 */
@PulumiTagMarker
public class NatRuleConditionArgsBuilder internal constructor() {
    private var description: Output<String>? = null

    private var destinationAddresses: Output<List<String>>? = null

    private var destinationPorts: Output<List<String>>? = null

    private var ipProtocols: Output<List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>? =
        null

    private var name: Output<String>? = null

    private var ruleConditionType: Output<String>? = null

    private var sourceAddresses: Output<List<String>>? = null

    private var sourceIpGroups: Output<List<String>>? = null

    /**
     * @param value Description of the rule condition.
     */
    @JvmName("dtftwufgrtunouvr")
    public suspend fun description(`value`: Output<String>) {
        this.description = value
    }

    /**
     * @param value List of destination IP addresses or Service Tags.
     */
    @JvmName("ivokyfjyirktehjp")
    public suspend fun destinationAddresses(`value`: Output<List<String>>) {
        this.destinationAddresses = value
    }

    @JvmName("jpjjlvaisdhckagx")
    public suspend fun destinationAddresses(vararg values: Output<String>) {
        this.destinationAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of destination IP addresses or Service Tags.
     */
    @JvmName("ocwxiegmpmhawabs")
    public suspend fun destinationAddresses(values: List<Output<String>>) {
        this.destinationAddresses = Output.all(values)
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("ffhpriwoerjedust")
    public suspend fun destinationPorts(`value`: Output<List<String>>) {
        this.destinationPorts = value
    }

    @JvmName("tqfaryjmjpeykysa")
    public suspend fun destinationPorts(vararg values: Output<String>) {
        this.destinationPorts = Output.all(values.asList())
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("otuacuuuireaibvn")
    public suspend fun destinationPorts(values: List<Output<String>>) {
        this.destinationPorts = Output.all(values)
    }

    /**
     * @param value Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("ajmjmyqayunfslav")
    public suspend
    fun ipProtocols(`value`: Output<List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>) {
        this.ipProtocols = value
    }

    @JvmName("ncokkbpypfbqbrhq")
    public suspend fun ipProtocols(
        vararg
        values: Output<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>,
    ) {
        this.ipProtocols = Output.all(values.asList())
    }

    /**
     * @param values Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("jsguwqlmjqfqnhoo")
    public suspend
    fun ipProtocols(values: List<Output<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>>) {
        this.ipProtocols = Output.all(values)
    }

    /**
     * @param value Name of the rule condition.
     */
    @JvmName("egmxfdsyclrwdywl")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Rule Condition Type.
     * Expected value is 'NatRuleCondition'.
     */
    @JvmName("nlvsdkgdvdddyuqi")
    public suspend fun ruleConditionType(`value`: Output<String>) {
        this.ruleConditionType = value
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("vqbutlgspetcotss")
    public suspend fun sourceAddresses(`value`: Output<List<String>>) {
        this.sourceAddresses = value
    }

    @JvmName("rtmqvcenbndneusq")
    public suspend fun sourceAddresses(vararg values: Output<String>) {
        this.sourceAddresses = Output.all(values.asList())
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("djlblvqwevotdoai")
    public suspend fun sourceAddresses(values: List<Output<String>>) {
        this.sourceAddresses = Output.all(values)
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("swxvuaqlnxabsoie")
    public suspend fun sourceIpGroups(`value`: Output<List<String>>) {
        this.sourceIpGroups = value
    }

    @JvmName("aeqqugsggdfvfuaj")
    public suspend fun sourceIpGroups(vararg values: Output<String>) {
        this.sourceIpGroups = Output.all(values.asList())
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("jsmqdptitfdemags")
    public suspend fun sourceIpGroups(values: List<Output<String>>) {
        this.sourceIpGroups = Output.all(values)
    }

    /**
     * @param value Description of the rule condition.
     */
    @JvmName("xysrauvygoymvkml")
    public suspend fun description(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.description = mapped
    }

    /**
     * @param value List of destination IP addresses or Service Tags.
     */
    @JvmName("pwkufhecsduwrnhx")
    public suspend fun destinationAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param values List of destination IP addresses or Service Tags.
     */
    @JvmName("aaetuvbisknpdqjb")
    public suspend fun destinationAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationAddresses = mapped
    }

    /**
     * @param value List of destination ports.
     */
    @JvmName("nqmprpdlgbrmgxim")
    public suspend fun destinationPorts(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param values List of destination ports.
     */
    @JvmName("qklsvscafsbqnrow")
    public suspend fun destinationPorts(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.destinationPorts = mapped
    }

    /**
     * @param value Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("xiguywerhnbcidig")
    public suspend
    fun ipProtocols(`value`: List<Either<String, FirewallPolicyRuleConditionNetworkProtocol>>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipProtocols = mapped
    }

    /**
     * @param values Array of FirewallPolicyRuleConditionNetworkProtocols.
     */
    @JvmName("neugbryeaibxycyq")
    public suspend fun ipProtocols(
        vararg
        values: Either<String, FirewallPolicyRuleConditionNetworkProtocol>,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ipProtocols = mapped
    }

    /**
     * @param value Name of the rule condition.
     */
    @JvmName("kascqevlhfxivygl")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Rule Condition Type.
     * Expected value is 'NatRuleCondition'.
     */
    @JvmName("ojqxdslpjikoyenx")
    public suspend fun ruleConditionType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ruleConditionType = mapped
    }

    /**
     * @param value List of source IP addresses for this rule.
     */
    @JvmName("gyvmsannxbhogrqn")
    public suspend fun sourceAddresses(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param values List of source IP addresses for this rule.
     */
    @JvmName("jubruxgwurkkmnci")
    public suspend fun sourceAddresses(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceAddresses = mapped
    }

    /**
     * @param value List of source IpGroups for this rule.
     */
    @JvmName("axpuggxxhbtbburr")
    public suspend fun sourceIpGroups(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    /**
     * @param values List of source IpGroups for this rule.
     */
    @JvmName("uteungkhpyvtipvu")
    public suspend fun sourceIpGroups(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sourceIpGroups = mapped
    }

    internal fun build(): NatRuleConditionArgs = NatRuleConditionArgs(
        description = description,
        destinationAddresses = destinationAddresses,
        destinationPorts = destinationPorts,
        ipProtocols = ipProtocols,
        name = name,
        ruleConditionType = ruleConditionType ?: throw PulumiNullFieldException("ruleConditionType"),
        sourceAddresses = sourceAddresses,
        sourceIpGroups = sourceIpGroups,
    )
}
